# Implementierung von IStringCalculator

from src.interfaces import IStringCalculator


class StringCalculator(IStringCalculator):
    def add(self, numbers: str) -> int:
        """
        Addiert beliebig viele Zahlen, getrennt durch Kommas, Zeilenumbrüche
        oder einen benutzerdefinierten Delimiter.
        Leere oder whitespace-only Einträge werden ignoriert.

        Beispiele:
        - ""              → 0
        - "1"             → 1
        - "1,2"           → 3
        - "1,2,3,4,5"     → 15
        - "1,,2"          → 3
        - "1, ,2"         → 3
        - ",,1,,2,,,"     → 3

        :param numbers: Zahlen als String, getrennt durch Komma
        :return: Summe der gültigen Zahlen als int
        """
        if not numbers:
            return 0

        delimiter = ","


        if numbers.startswith("//"):
            header, numbers = numbers.split("\n", 1)

            # Mehrzeichen-Delimiter: z.B. //[***]
            if header.startswith("//[") and header.endswith("]"):
                delimiter = header[3:-1]  # Extrahiere z.B. "***"
            else:
                delimiter = header[2:]  # Einzeichen-Delimiter

        # Ersetze \n durch Komma (Standard)
        numbers = numbers.replace("\n", ",")

        # Delimiter ersetzen durch Komma (evtl. mehrere Zeichen)
        numbers = numbers.replace(delimiter, ",")

        number_list = numbers.split(",")

        # Ignoriere leere oder whitespace-only Einträge
        cleaned_numbers = [
            int(n.strip()) for n in number_list if n.strip() != ""
        ]

        # Negativ-Prüfung
        negatives = [n for n in cleaned_numbers if n < 0]
        if negatives:
            raise ValueError(f"negatives not allowed: {', '.join(map(str, negatives))}")

        # Zahlen > 1000 ignorieren
        cleaned_numbers = [n for n in cleaned_numbers if n <= 1000]

        return sum(cleaned_numbers)