import unittest
from src.my.string_calculator import StringCalculator
#from src.Alma.string_calculator_Alma import StringCalculator

class TestStringCalculator(unittest.TestCase):
    def setUp(self):
        self.calculator = StringCalculator()

    def test_empty_string(self):
        self.assertEqual(self.calculator.add(""), 0)

    def test_single_number(self):
        self.assertEqual(self.calculator.add("1"), 1)

    def test_two_numbers(self):
        self.assertEqual(self.calculator.add("1,2"), 3)

    def test_multiple_numbers(self):
        self.assertEqual(self.calculator.add("1,2,3,4,5"), 15)

    def test_numbers_with_newline(self):
        self.assertEqual(self.calculator.add("1\n2,3"), 6)

    def test_numbers_with_multiple_newlines(self):
        self.assertEqual(self.calculator.add("1\n2\n3\n4\n5"), 15)

    def test_negative_number(self):
        with self.assertRaises(ValueError) as context:
            self.calculator.add("1,-2,3")
        self.assertEqual(str(context.exception), "Negatives not allowed: -2")

    def test_multiple_negative_numbers(self):
        with self.assertRaises(ValueError) as context:
            self.calculator.add("1,-2,-3,4")
        self.assertEqual(str(context.exception), "Negatives not allowed: -2, -3")

    def test_custom_delimiter(self):
        self.assertEqual(self.calculator.add("//;\n1;2"), 3)

    def test_custom_delimiter_with_newline(self):
        self.assertEqual(self.calculator.add("//;\n1;2\n3"), 6)

    def test_custom_delimiter_with_multiple_numbers(self):
        self.assertEqual(self.calculator.add("//|\n1|2|3|4"), 10)

    def test_numbers_greater_than_1000(self):
        self.assertEqual(self.calculator.add("2,1001"), 2)

    def test_numbers_greater_than_1000_with_custom_delimiter(self):
        self.assertEqual(self.calculator.add("//;\n2;1001"), 2)

    def test_long_delimiter(self):
        self.assertEqual(self.calculator.add("//[***]\n1***2***3"), 6)

    def test_long_delimiter_with_multiple_numbers(self):
        self.assertEqual(self.calculator.add("//[---]\n1---2---3---4"), 10)


if __name__ == "__main__":
    unittest.main()