import unittest
#from src.my.string_calculator import StringCalculator
#from src.Alma.string_calculator_Alma import StringCalculator
#from src.Lasse.string_calculator_Lasse import StringCalculator
#from src.Daniel.string_calculator_Daniel import StringCalculator
#from src.Hatice.string_calculator_Hatice import StringCalculator
#from src.Muhamed.string_calculator_Muhamed import StringCalculator
from src.Marvin.string_calculator_Marvin import StringCalculator
#from src.Wasilios.string_calculator_Wasilios import StringCalculator


class TestStringCalculator(unittest.TestCase):
    def setUp(self):
        # Vor jedem Test wird eine Instanz des Calculators erstellt
        self.calc = StringCalculator()

    def test_add_empty_string(self):
        # Leerer String → 0
        self.assertEqual(self.calc.add(""), 0)

    def test_add_single_number(self):
        # Ein einzelner Wert → int
        self.assertEqual(self.calc.add("1"), 1)

    def test_add_two_numbers(self):
        # Zwei Zahlen → Summe
        self.assertEqual(self.calc.add("1,2"), 3)

    def test_add_multiple_numbers(self):
        # Mehr als zwei Zahlen → Summe
        self.assertEqual(self.calc.add("1,2,3"), 6)
        self.assertEqual(self.calc.add("1,2,3,4,5"), 15)

    def test_add_ignores_empty_entries(self):
        # Leere Einträge ignorieren → Summe
        self.assertEqual(self.calc.add("1,,2"), 3)
        self.assertEqual(self.calc.add("1, ,2"), 3)
        self.assertEqual(self.calc.add(",,1,,2,,,"), 3)

    def test_add_with_newlines_between_numbers(self):
        # Zeilenumbrüche als Trennzeichen erlauben → Summe
        self.assertEqual(self.calc.add("1\n2,3"), 6)
        self.assertEqual(self.calc.add("1,2\n3"), 6)
        self.assertEqual(self.calc.add("1\n2\n3"), 6)

    def test_add_raises_exception_on_negative_number(self):
        # Negative Zahlen → Exception mit allen negativen Werten
        with self.assertRaises(ValueError) as context:
            self.calc.add("1,-2")
        self.assertIn("negatives not allowed: -2", str(context.exception))

    def test_add_raises_exception_on_multiple_negatives(self):
        # Negative Zahlen → Exception mit allen negativen Werten
        with self.assertRaises(ValueError) as context:
            self.calc.add("-1,-2,3")
        self.assertIn("negatives not allowed: -1, -2", str(context.exception))

    def test_add_with_custom_delimiter(self):
        # Benutzerdefinierter Delimiter über Präfix: "//<delimiter>\n"
        self.assertEqual(self.calc.add("//;\n1;2"), 3)
        self.assertEqual(self.calc.add("//|\n4|5|6"), 15)
        self.assertEqual(self.calc.add("//_\n7_8_9"), 24)

    def test_add_ignores_numbers_greater_than_1000(self):
        # Zahlen größer als 1000 ignorieren
        self.assertEqual(self.calc.add("2,1001"), 2)
        self.assertEqual(self.calc.add("1000,1"), 1001)
        self.assertEqual(self.calc.add("1234,1001,3"), 3)

    def test_add_with_multi_char_delimiter(self):
        # Delimiter mit beliebiger Länge (Format: //[delimiter]\n)
        self.assertEqual(self.calc.add("//[***]\n1***2***3"), 6)
        self.assertEqual(self.calc.add("//[abc]\n4abc5abc6"), 15)
        self.assertEqual(self.calc.add("//[+]\n1+2+3"), 6)

if __name__ == "__main__":
    unittest.main()